@@ -1,11 +1,11 @@
 import json
 
 import bleach
-import commonmark
 from django.utils.html import conditional_escape, escape, format_html, mark_safe
 from jsonschema.exceptions import ValidationError
 from libcove.lib.common import common_checks_context, get_additional_codelist_values, unique_ids, validator
 from libcove.lib.tools import decimal_default
+from markdown_it import MarkdownIt
 
 from libcoveocds.lib.additional_checks import TEST_CLASSES, run_additional_checks
 from libcoveocds.lib.common_checks import (
@@ -15,6 +15,8 @@ from libcoveocds.lib.common_checks import (
     lookup_schema,
 )
 
+md = MarkdownIt()
+
 validation_error_lookup = {
     "date-time": mark_safe(
         'Incorrect date format. Dates should use the form YYYY-MM-DDT00:00:00Z. Learn more about <a href="https://standard.open-contracting.org/latest/en/schema/reference/#date">dates in OCDS</a>.'  # noqa: E501
@@ -27,9 +29,11 @@ def unique_ids_or_ocids(validator, ui, instance, schema):
     # we look out for this $ref — this may change if the way the schema files
     # are structured changes.
     if schema.get("items") == {"$ref": "#/definitions/record"}:
-        return unique_ids(validator, ui, instance, schema, id_name="ocid")
+        return unique_ids(validator, ui, instance, schema, id_names=["ocid"])
+    elif "$ref" in schema.get("items", {}) and schema["items"]["$ref"].endswith("release-schema.json"):
+        return unique_ids(validator, ui, instance, schema, id_names=["ocid", "id"])
     else:
-        return unique_ids(validator, ui, instance, schema, id_name="id")
+        return unique_ids(validator, ui, instance, schema, id_names=["id"])
 
 
 def oneOf_draft4(validator, oneOf, instance, schema):
@@ -138,9 +142,7 @@ def common_checks_ocds(context, upload_dir, json_data, schema_obj, api=False, ca
             if "description" in schema_block:
                 error["schema_title"] = escape(schema_block.get("title", ""))
                 error["schema_description_safe"] = mark_safe(
-                    bleach.clean(
-                        commonmark.commonmark(schema_block["description"]), tags=bleach.sanitizer.ALLOWED_TAGS + ["p"]
-                    )
+                    bleach.clean(md.render(schema_block["description"]), tags=bleach.sanitizer.ALLOWED_TAGS + ["p"])
                 )
             if ref_info:
                 ref = ref_info["reference"]["$ref"]
